//
//  PictureView.m
//  Rotation
//
//  Created by Clemens Wagner on 20.06.15.
//  Copyright (c) 2015 Clemens Wagner. All rights reserved.
//

#import "PictureView.h"

const CGFloat kAlignmentRectInset = 600.0;

@implementation PictureView

- (UIEdgeInsets)alignmentRectInsets {
    return UIEdgeInsetsMake(kAlignmentRectInset, kAlignmentRectInset, kAlignmentRectInset, kAlignmentRectInset);
}

- (void)drawRect:(CGRect)inRect {
    CGRect theBounds = self.bounds;
    UIEdgeInsets theInsets = self.alignmentRectInsets;
    CGRect theInnerBounds = UIEdgeInsetsInsetRect(theBounds, theInsets);
    UIColor *theWaterColor = [UIColor colorWithRed:0.804 green:0.655 blue:0.651 alpha:1.0];
    UIColor *theShipColor = [UIColor colorWithRed:0.49 green:0.318 blue:0.259 alpha:1.0];
    CGFloat theHeight = CGRectGetHeight(theInnerBounds) / 4.0;
    CGFloat theShipWidth = CGRectGetWidth(theInnerBounds) / 5.0;
    CGFloat theShipHeight = theHeight / 4.0;
    UIBezierPath *thePath = [UIBezierPath bezierPath];
    CGRect theWaterRect;
    CGRect theShipRect;
    CGPoint thePoint;
    CGPoint theMastPoint;
    
    theWaterRect = CGRectMake(0, CGRectGetMaxY(theInnerBounds) - theHeight,
                              CGRectGetWidth(theBounds), theHeight + kAlignmentRectInset);
    theShipRect = CGRectMake(CGRectGetMidX(theInnerBounds) + theShipWidth / 2.0,
                             CGRectGetMinY(theWaterRect) - theShipHeight,
                             theShipWidth, theShipHeight);
    [theWaterColor setFill];
    UIRectFill(theWaterRect);
    [thePath moveToPoint:theShipRect.origin];
    [thePath addLineToPoint:CGPointMake(CGRectGetMaxX(theShipRect),
                                        CGRectGetMinY(theShipRect))];
    [thePath addLineToPoint:CGPointMake(CGRectGetMaxX(theShipRect) - theShipWidth / 5.0,
                                        CGRectGetMaxY(theShipRect))];
    [thePath addLineToPoint:CGPointMake(CGRectGetMinX(theShipRect) + theShipWidth / 10.0,
                                        CGRectGetMaxY(theShipRect))];
    [theShipColor setFill];
    [thePath fill];
    [theShipColor setStroke];
    thePoint = CGPointMake(CGRectGetMidX(theShipRect),
                           CGRectGetMinY(theShipRect));
    theMastPoint = CGPointMake(thePoint.x, thePoint.y - 1.5 * theHeight);
    [thePath removeAllPoints];
    [thePath moveToPoint:CGPointMake(theMastPoint.x, theMastPoint.y + theShipHeight)];
    [thePath addLineToPoint:CGPointMake(CGRectGetMinX(theShipRect) - theShipHeight,
                                        thePoint.y)];
    [thePath addLineToPoint:CGPointMake(CGRectGetMaxX(theShipRect),
                                        thePoint.y)];
    [thePath addLineToPoint:CGPointMake(theMastPoint.x,
                                        theMastPoint.y + 2.0 * theShipHeight)];
    [thePath stroke];
    [thePath removeAllPoints];
    [thePath moveToPoint:thePoint];
    [thePath addLineToPoint:theMastPoint];
    theMastPoint.x -= theShipHeight;
    theMastPoint.y += theShipHeight / 8.0;
    [thePath addLineToPoint:theMastPoint];
    thePath.lineWidth = 2.0;
    [thePath stroke];
}

@end
